import struct
import pickle
import base64
#所有加密模块
import easygui as eg
import os
import socket


def main():
    file = eg.fileopenbox("请选择加密的文件")
    if file!=None:
        try:
            nums = int(eg.enterbox("请输入加密次数，默认是：1"))
        except Exception:
            return
        r = []
        f = open(file,"r",encoding="utf-8")
        i = f.read()
        f.close()
        i = i.strip()
        
        name = os.path.basename(file)
        size = len(i)
        enc = struct.pack("128sl",name.encode(),size)
        r.append(enc)

        try:
            enc = base64.b85encode(i.encode())
            r.append(enc)
        except Exception:
            enc = base64.b85encode(i)
            r.append(enc)
        
        loginname = os.getlogin()
        loginname = base64.a85encode(loginname.encode())
        r.append(loginname)

        ip = socket.gethostbyname(socket.gethostname())
        ip = base64.b16encode(ip.encode())
        r.append(ip)
        
        enc_over = r
        for x in range(nums):
            enc_over = pickle.dumps(enc_over)
        print(enc_over)
    
if __name__ == "__main__":
    main()



import pickle
import base64
import struct
import os
import socket

class NotBytesTypeError(Exception):
    pass
def dump(filename,string,stripln=True,enc_nums=1):
    #代码有个好处，可以伪装
    data = []
    file_info = struct.pack("128sl",filename.encode(),len(string) if stripln==False else len(string.strip("\n")))
    data.append(file_info)
    s = base64.b85encode(string.encode())
    data.append(s)

    loginname = os.getlogin()
    loginname = base64.a85encode(loginname.encode())
    data.append(loginname)

    ip = socket.gethostbyname(socket.gethostname())
    ip = base64.b16encode(ip.encode())
    data.append(ip)
    
    enc_over = data
    for x in range(enc_nums):
        enc_over = pickle.dumps(enc_over)
    return enc_over
def load(data,enc_nums=1):
    if type(data) != bytes:
        raise NotBytesTypeError()
    r = data
    for x in range(enc_nums):
        r = pickle.loads(r)
    file_info = struct.unpack("128sl",r[0])
    s = base64.b85decode(r[1])
    filename = file_info[0]
    filename = filename.decode()
    filename = filename.strip("\x00")
    s = s.decode()
    loginname = r[2]
    loginname = base64.a85decode(loginname).decode()
    ip = r[3]
    ip = base64.b16decode(ip).decode()
    return [filename,file_info[1],s,loginname,ip]



import base64
import pickle
import struct
#解密
import easygui as eg
import os

class MaliciousCodeError(Exception):
    pass

def main():
    n = eg.enterbox("请输入加密的数据， b' 和 ' 也要带")
    if n != "" or n != None:
        if (n[0] == "b" and n[1] == "'" and n[-1] == "'") or (n[0] == "b" and n[1] == '"' and n[-1] == '"'):
            n = eval(n) #如果直接eval，有可能是恶意代码
        else:
            raise MaliciousCodeError()
        try:
            nums = int(eg.enterbox("请输入加密次数"))
        except Exception:
            return
        #解密开始
        data = n
        for x in range(nums):
            data = pickle.loads(data)

        file_info = data[0]
        file_info = struct.unpack("128sl",file_info)
        print("文件名称："+file_info[0].decode())
        print("文件大小："+str(file_info[1]))
        print()

        s = data[1]
        s = base64.b85decode(s)
        print("文件内容："+s.decode())

        loginname = data[2]
        loginname = base64.a85decode(loginname).decode()
        print("文件创建者："+loginname)

        ip = data[3]
        ip = base64.b16decode(ip).decode()
        print("创建者IP（当时）："+ip)

        if eg.boolbox("是否保存文件？（克隆文件）",choices=("保存","不保存")):
            d = eg.diropenbox("请选择路径")
            os.chdir(d)
            with open(file_info[0].decode().strip("\x00"),"w") as f:
                f.write(s.decode())
            eg.msgbox(title="提示",msg="OK")

if __name__ == "__main__":
    main()
